gettid

Function gettid 

pub(crate) fn gettid() -> i64
Returns the calling thread’s OS tid (gettid syscall) so a stop/start issued from inside the Python callback can detect it is on the capture thread and avoid self-joining.